@@ -21,12 +21,10 @@ sub keymap {
 
 		# init win mit grunddesign
 		$Kephra::temp{'keymap'}{'dialog_active'} = 1;
+		my $l18n = Kephra::Localisation::strings->{dialogs}{keyboard_map};
 		my $keymap_win = Wx::Frame->new(
-			$frame,
-			-1,
-			' ' . $Kephra::localisation{'dialogs'}{'keyboard_map'}{'title'},
-			[ 10,  10 ],
-			[ 420, 460 ],
+			$frame, -1, ' ' . $l18n->{title},
+			[ 10,  10 ], [ 420, 460 ],
 			wxNO_FULL_REPAINT_ON_RESIZE | wxSYSTEM_MENU | wxCAPTION
 				| wxMINIMIZE_BOX | wxCLOSE_BOX | wxRESIZE_BORDER,
 		);
